==> zio-aws-opsworkscm_2.12-5.17.104.3-sources.jar: zio/aws/opsworkscm/model/package.scala <==
package zio.aws.opsworkscm
import zio.prelude.Subtype
import zio.aws.opsworkscm.model.primitives.TagKey
import java.time.Instant
import zio.aws.opsworkscm.model.primitives.MaxResults.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object AWSOpsWorksCMResourceArn extends Subtype[String]
    type AWSOpsWorksCMResourceArn =
      zio.aws.opsworkscm.model.primitives.AWSOpsWorksCMResourceArn.Type
    object AttributeName extends Subtype[String]
    type AttributeName = zio.aws.opsworkscm.model.primitives.AttributeName.Type
    object AttributeValue extends Subtype[String]
    type AttributeValue =
      zio.aws.opsworkscm.model.primitives.AttributeValue.Type
    object BackupId extends Subtype[String]
    type BackupId = zio.aws.opsworkscm.model.primitives.BackupId.Type
    object BackupRetentionCountDefinition extends Subtype[Int]
    type BackupRetentionCountDefinition =
      zio.aws.opsworkscm.model.primitives.BackupRetentionCountDefinition.Type
    object CustomCertificate extends Subtype[String]
    type CustomCertificate =
      zio.aws.opsworkscm.model.primitives.CustomCertificate.Type
    object CustomDomain extends Subtype[String]
    type CustomDomain = zio.aws.opsworkscm.model.primitives.CustomDomain.Type
    object CustomPrivateKey extends Subtype[String]
    type CustomPrivateKey =
      zio.aws.opsworkscm.model.primitives.CustomPrivateKey.Type
    object EngineAttributeName extends Subtype[String]
    type EngineAttributeName =
      zio.aws.opsworkscm.model.primitives.EngineAttributeName.Type
    object EngineAttributeValue extends Subtype[String]
    type EngineAttributeValue =
      zio.aws.opsworkscm.model.primitives.EngineAttributeValue.Type
    object InstanceProfileArn extends Subtype[String]
    type InstanceProfileArn =
      zio.aws.opsworkscm.model.primitives.InstanceProfileArn.Type
    object Integer extends Subtype[Int]
    type Integer = zio.aws.opsworkscm.model.primitives.Integer.Type
    object KeyPair extends Subtype[String]
    type KeyPair = zio.aws.opsworkscm.model.primitives.KeyPair.Type
    object MaxResults extends Subtype[Int]
    type MaxResults = zio.aws.opsworkscm.model.primitives.MaxResults.Type
    object NextToken extends Subtype[String]
    type NextToken = zio.aws.opsworkscm.model.primitives.NextToken.Type
    object NodeAssociationStatusToken extends Subtype[String]
    type NodeAssociationStatusToken =
      zio.aws.opsworkscm.model.primitives.NodeAssociationStatusToken.Type
    object NodeName extends Subtype[String]
    type NodeName = zio.aws.opsworkscm.model.primitives.NodeName.Type
    object ServerName extends Subtype[String]
    type ServerName = zio.aws.opsworkscm.model.primitives.ServerName.Type
    object ServiceRoleArn extends Subtype[String]
    type ServiceRoleArn =
      zio.aws.opsworkscm.model.primitives.ServiceRoleArn.Type
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.opsworkscm.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue = zio.aws.opsworkscm.model.primitives.TagValue.Type
    object TimeWindowDefinition extends Subtype[String]
    type TimeWindowDefinition =
      zio.aws.opsworkscm.model.primitives.TimeWindowDefinition.Type
    object Timestamp extends Subtype[Instant]
    type Timestamp = zio.aws.opsworkscm.model.primitives.Timestamp.Type
  }
  type AccountAttributes = List[zio.aws.opsworkscm.model.AccountAttribute]
  type Backups = List[zio.aws.opsworkscm.model.Backup]
  type EngineAttributes = List[zio.aws.opsworkscm.model.EngineAttribute]
  type ServerEvents = List[zio.aws.opsworkscm.model.ServerEvent]
  type Servers = List[zio.aws.opsworkscm.model.Server]
  type Strings = List[String]
  type TagKeyList = List[TagKey]
  type TagList = List[zio.aws.opsworkscm.model.Tag]
}

==> zio-aws-opsworkscm_2.13-5.19.26.1-sources.jar: zio/aws/opsworkscm/model/package.scala <==
package zio.aws.opsworkscm
import zio.prelude.Subtype
import zio.aws.opsworkscm.model.primitives.TagKey
import java.time.Instant
import zio.aws.opsworkscm.model.primitives.MaxResults.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object AWSOpsWorksCMResourceArn extends Subtype[String]
    type AWSOpsWorksCMResourceArn =
      zio.aws.opsworkscm.model.primitives.AWSOpsWorksCMResourceArn.Type
    object AttributeName extends Subtype[String]
    type AttributeName = zio.aws.opsworkscm.model.primitives.AttributeName.Type
    object AttributeValue extends Subtype[String]
    type AttributeValue =
      zio.aws.opsworkscm.model.primitives.AttributeValue.Type
    object BackupId extends Subtype[String]
    type BackupId = zio.aws.opsworkscm.model.primitives.BackupId.Type
    object BackupRetentionCountDefinition extends Subtype[Int]
    type BackupRetentionCountDefinition =
      zio.aws.opsworkscm.model.primitives.BackupRetentionCountDefinition.Type
    object CustomCertificate extends Subtype[String]
    type CustomCertificate =
      zio.aws.opsworkscm.model.primitives.CustomCertificate.Type
    object CustomDomain extends Subtype[String]
    type CustomDomain = zio.aws.opsworkscm.model.primitives.CustomDomain.Type
    object CustomPrivateKey extends Subtype[String]
    type CustomPrivateKey =
      zio.aws.opsworkscm.model.primitives.CustomPrivateKey.Type
    object EngineAttributeName extends Subtype[String]
    type EngineAttributeName =
      zio.aws.opsworkscm.model.primitives.EngineAttributeName.Type
    object EngineAttributeValue extends Subtype[String]
    type EngineAttributeValue =
      zio.aws.opsworkscm.model.primitives.EngineAttributeValue.Type
    object InstanceProfileArn extends Subtype[String]
    type InstanceProfileArn =
      zio.aws.opsworkscm.model.primitives.InstanceProfileArn.Type
    type Integer = Int
    object KeyPair extends Subtype[String]
    type KeyPair = zio.aws.opsworkscm.model.primitives.KeyPair.Type
    object MaxResults extends Subtype[Int]
    type MaxResults = zio.aws.opsworkscm.model.primitives.MaxResults.Type
    object NextToken extends Subtype[String]
    type NextToken = zio.aws.opsworkscm.model.primitives.NextToken.Type
    object NodeAssociationStatusToken extends Subtype[String]
    type NodeAssociationStatusToken =
      zio.aws.opsworkscm.model.primitives.NodeAssociationStatusToken.Type
    object NodeName extends Subtype[String]
    type NodeName = zio.aws.opsworkscm.model.primitives.NodeName.Type
    object ServerName extends Subtype[String]
    type ServerName = zio.aws.opsworkscm.model.primitives.ServerName.Type
    object ServiceRoleArn extends Subtype[String]
    type ServiceRoleArn =
      zio.aws.opsworkscm.model.primitives.ServiceRoleArn.Type
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.opsworkscm.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue = zio.aws.opsworkscm.model.primitives.TagValue.Type
    object TimeWindowDefinition extends Subtype[String]
    type TimeWindowDefinition =
      zio.aws.opsworkscm.model.primitives.TimeWindowDefinition.Type
    object Timestamp extends Subtype[Instant]
    type Timestamp = zio.aws.opsworkscm.model.primitives.Timestamp.Type
  }
  type AccountAttributes = List[zio.aws.opsworkscm.model.AccountAttribute]
  type Backups = List[zio.aws.opsworkscm.model.Backup]
  type EngineAttributes = List[zio.aws.opsworkscm.model.EngineAttribute]
  type ServerEvents = List[zio.aws.opsworkscm.model.ServerEvent]
  type Servers = List[zio.aws.opsworkscm.model.Server]
  type Strings = List[String]
  type TagKeyList = List[TagKey]
  type TagList = List[zio.aws.opsworkscm.model.Tag]
}
